<?php

/**
 * Registers one or more extended processors. These are classes implementing the
 * SearchApiExtendedProcessorInterface interface which can be used at search
 * time to pre-process item data or the search query, and to
 * post-process the returned search results. Extended processors can also provide
 * a UI to allow end users to configure the processor per-query.
 *
 * @see SearchApiExtendedProcessorInterface
 *
 * @return array
 *   An associative array keyed by the extended processor id and containing arrays
 *   with the following keys:
 *   - name: The name to display for this extended processor.
 *   - description: A short description of what the extended processor does at each
 *     phase.
 *   - class: The extended processor class, which has to implement the
 *     SearchApiExtendedProcessorInterface interface.
 *   - weight: (optional) Defines the order in which extended processors are
 *     displayed  (and, therefore, invoked) by default. Defaults to 0.
 */
function hook_search_api_extended_processor_info() {
  $extenders['example_extender'] = array(
    'name' => t('Example processor'),
    'description' => t('Allows per-query configurable manipulation.'),
    'class' => 'ExampleSearchApiExtendedProcessor',
    'weight' => -1,
  );

  return $extenders;
}

/**
 * Alter the definition of extended processors provided by other modules.
 *
 * @param $extended_processors
 *   An associative array of extended processors. See
 *   hook_search_api_extended_processor_info() for details of its contents.
 *
 * @see hook_search_api_extended_processor_info()
 */
function hook_search_api_extended_processor_info_alter(&$extended_processors) {
  // Don't allow the 'example_extender' to be defined.
  unset($extended_processors['example_processor']);
}
